summaryrefslogtreecommitdiffstats
path: root/chromium/net/base
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/net/base')
-rw-r--r--chromium/net/base/load_timing_info.h2
-rw-r--r--chromium/net/base/net_error_list.h9
-rw-r--r--chromium/net/base/network_change_notifier.cc4
-rw-r--r--chromium/net/base/network_change_notifier_posix.cc (renamed from chromium/net/base/network_change_notifier_chromeos.cc)58
-rw-r--r--chromium/net/base/network_change_notifier_posix.h (renamed from chromium/net/base/network_change_notifier_chromeos.h)28
-rw-r--r--chromium/net/base/network_change_notifier_posix_unittest.cc (renamed from chromium/net/base/network_change_notifier_chromeos_unittest.cc)20
-rw-r--r--chromium/net/base/registry_controlled_domains/effective_tld_names.dat80
-rw-r--r--chromium/net/base/registry_controlled_domains/effective_tld_names.gperf44
8 files changed, 170 insertions, 75 deletions
diff --git a/chromium/net/base/load_timing_info.h b/chromium/net/base/load_timing_info.h
index d5df508c7ec..73ff26a9df5 100644
--- a/chromium/net/base/load_timing_info.h
+++ b/chromium/net/base/load_timing_info.h
@@ -58,7 +58,7 @@ namespace net {
// have SSL times. One exception to this is when a proxy server itself returns
// a redirect response. In this case, the connect times treat the proxy as the
// host. The send and receive times will all be null, however.
-// See HttpNetworkTransaction::OnHttpsProxyTunnelResponse.
+// See HttpNetworkTransaction::OnHttpsProxyTunnelResponseRedirect.
// TODO(mmenke): Is this worth fixing?
//
struct NET_EXPORT LoadTimingInfo {
diff --git a/chromium/net/base/net_error_list.h b/chromium/net/base/net_error_list.h
index 61fbd8e7c14..b7b7063fc0e 100644
--- a/chromium/net/base/net_error_list.h
+++ b/chromium/net/base/net_error_list.h
@@ -261,9 +261,12 @@ NET_ERROR(NETWORK_ACCESS_DENIED, -138)
NET_ERROR(TEMPORARILY_THROTTLED, -139)
// A request to create an SSL tunnel connection through the HTTPS proxy
-// received a non-200 (OK) and non-407 (Proxy Auth) response. The response
-// body might include a description of why the request failed.
-NET_ERROR(HTTPS_PROXY_TUNNEL_RESPONSE, -140)
+// received a 302 (temporary redirect) response. The response body might
+// include a description of why the request failed.
+//
+// TODO(https://crbug.com/928551): This is deprecated and should not be used by
+// new code.
+NET_ERROR(HTTPS_PROXY_TUNNEL_RESPONSE_REDIRECT, -140)
// We were unable to sign the CertificateVerify data of an SSL client auth
// handshake with the client certificate's private key.
diff --git a/chromium/net/base/network_change_notifier.cc b/chromium/net/base/network_change_notifier.cc
index a4c5486a888..55772fc82a6 100644
--- a/chromium/net/base/network_change_notifier.cc
+++ b/chromium/net/base/network_change_notifier.cc
@@ -34,7 +34,7 @@
#elif defined(OS_MACOSX)
#include "net/base/network_change_notifier_mac.h"
#elif defined(OS_CHROMEOS)
-#include "net/base/network_change_notifier_chromeos.h"
+#include "net/base/network_change_notifier_posix.h"
#elif defined(OS_FUCHSIA)
#include "net/base/network_change_notifier_fuchsia.h"
#endif
@@ -213,7 +213,7 @@ NetworkChangeNotifier* NetworkChangeNotifier::Create() {
CHECK(false);
return NULL;
#elif defined(OS_CHROMEOS)
- return new NetworkChangeNotifierChromeos();
+ return new NetworkChangeNotifierPosix(CONNECTION_UNKNOWN, SUBTYPE_UNKNOWN);
#elif defined(OS_LINUX)
return new NetworkChangeNotifierLinux(std::unordered_set<std::string>());
#elif defined(OS_MACOSX)
diff --git a/chromium/net/base/network_change_notifier_chromeos.h b/chromium/net/base/network_change_notifier_posix.h
index 822d3f6cf65..37e6ae405ad 100644
--- a/chromium/net/base/network_change_notifier_chromeos.h
+++ b/chromium/net/base/network_change_notifier_posix.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef NET_BASE_NETWORK_CHANGE_NOTIFIER_CHROMEOS_H_
-#define NET_BASE_NETWORK_CHANGE_NOTIFIER_CHROMEOS_H_
+#ifndef NET_BASE_NETWORK_CHANGE_NOTIFIER_POSIX_H_
+#define NET_BASE_NETWORK_CHANGE_NOTIFIER_POSIX_H_
#include "base/gtest_prod_util.h"
#include "base/macros.h"
@@ -18,13 +18,15 @@
namespace net {
// A NetworkChangeNotifier that needs to be told about network changes by some
-// other object. This class can't directly listen for network changes because
-// on ChromeOS only objects running in the browser process can listen for
-// network state changes.
-class NET_EXPORT NetworkChangeNotifierChromeos : public NetworkChangeNotifier {
+// other object. This class can't directly listen for network changes because on
+// ChromeOS and Android only objects running in the browser process can listen
+// for network state changes.
+class NET_EXPORT NetworkChangeNotifierPosix : public NetworkChangeNotifier {
public:
- NetworkChangeNotifierChromeos();
- ~NetworkChangeNotifierChromeos() override;
+ NetworkChangeNotifierPosix(
+ NetworkChangeNotifier::ConnectionType initial_connection_type,
+ NetworkChangeNotifier::ConnectionSubtype initial_connection_subtype);
+ ~NetworkChangeNotifierPosix() override;
// These methods are used to notify this object that a network property has
// changed. These must be called from the thread that owns this object.
@@ -45,9 +47,7 @@ class NET_EXPORT NetworkChangeNotifierChromeos : public NetworkChangeNotifier {
ConnectionType* connection_type) const override;
private:
- FRIEND_TEST_ALL_PREFIXES(NetworkChangeNotifierChromeosTest,
- ConnectionTypeFromShill);
- friend class NetworkChangeNotifierChromeosTest;
+ friend class NetworkChangeNotifierPosixTest;
class DnsConfigService;
@@ -75,7 +75,7 @@ class NET_EXPORT NetworkChangeNotifierChromeos : public NetworkChangeNotifier {
// Calculates parameters used for network change notifier online/offline
// signals.
static NetworkChangeNotifier::NetworkChangeCalculatorParams
- NetworkChangeCalculatorParamsChromeos();
+ NetworkChangeCalculatorParamsPosix();
THREAD_CHECKER(thread_checker_);
@@ -86,9 +86,9 @@ class NET_EXPORT NetworkChangeNotifierChromeos : public NetworkChangeNotifier {
NotifierThread notifier_thread_;
- DISALLOW_COPY_AND_ASSIGN(NetworkChangeNotifierChromeos);
+ DISALLOW_COPY_AND_ASSIGN(NetworkChangeNotifierPosix);
};
} // namespace net
-#endif // NET_BASE_NETWORK_CHANGE_NOTIFIER_CHROMEOS_H_
+#endif // NET_BASE_NETWORK_CHANGE_NOTIFIER_POSIX_H_
diff --git a/chromium/net/base/network_change_notifier_chromeos_unittest.cc b/chromium/net/base/network_change_notifier_posix_unittest.cc
index 00d7ad234fa..c540877f651 100644
--- a/chromium/net/base/network_change_notifier_chromeos_unittest.cc
+++ b/chromium/net/base/network_change_notifier_posix_unittest.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "net/base/network_change_notifier_chromeos.h"
+#include "net/base/network_change_notifier_posix.h"
#include "base/test/scoped_task_environment.h"
#include "net/base/network_change_notifier.h"
@@ -10,23 +10,25 @@
namespace net {
-class NetworkChangeNotifierChromeosTest : public testing::Test {
+class NetworkChangeNotifierPosixTest : public testing::Test {
public:
- NetworkChangeNotifierChromeosTest()
+ NetworkChangeNotifierPosixTest()
: scoped_task_environment_(
base::test::ScopedTaskEnvironment::MainThreadType::MOCK_TIME),
- notifier_(new NetworkChangeNotifierChromeos()) {}
+ notifier_(new NetworkChangeNotifierPosix(
+ NetworkChangeNotifier::CONNECTION_UNKNOWN,
+ NetworkChangeNotifier::SUBTYPE_UNKNOWN)) {}
void FastForwardUntilIdle() {
scoped_task_environment_.FastForwardUntilNoTasksRemain();
}
- NetworkChangeNotifierChromeos* notifier() { return notifier_.get(); }
+ NetworkChangeNotifierPosix* notifier() { return notifier_.get(); }
private:
base::test::ScopedTaskEnvironment scoped_task_environment_;
net::NetworkChangeNotifier::DisableForTest mock_notifier_disabler_;
- std::unique_ptr<NetworkChangeNotifierChromeos> notifier_;
+ std::unique_ptr<NetworkChangeNotifierPosix> notifier_;
};
class MockIPAddressObserver : public NetworkChangeNotifier::IPAddressObserver {
@@ -34,7 +36,7 @@ class MockIPAddressObserver : public NetworkChangeNotifier::IPAddressObserver {
MOCK_METHOD0(OnIPAddressChanged, void());
};
-TEST_F(NetworkChangeNotifierChromeosTest, OnIPAddressChanged) {
+TEST_F(NetworkChangeNotifierPosixTest, OnIPAddressChanged) {
testing::StrictMock<MockIPAddressObserver> observer;
NetworkChangeNotifier::AddIPAddressObserver(&observer);
@@ -51,7 +53,7 @@ class MockNetworkChangeObserver
MOCK_METHOD1(OnNetworkChanged, void(NetworkChangeNotifier::ConnectionType));
};
-TEST_F(NetworkChangeNotifierChromeosTest, OnNetworkChanged) {
+TEST_F(NetworkChangeNotifierPosixTest, OnNetworkChanged) {
testing::StrictMock<MockNetworkChangeObserver> observer;
NetworkChangeNotifier::AddNetworkChangeObserver(&observer);
@@ -71,7 +73,7 @@ class MockMaxBandwidthObserver
void(double, NetworkChangeNotifier::ConnectionType));
};
-TEST_F(NetworkChangeNotifierChromeosTest, OnMaxBandwidthChanged) {
+TEST_F(NetworkChangeNotifierPosixTest, OnMaxBandwidthChanged) {
testing::StrictMock<MockMaxBandwidthObserver> observer;
NetworkChangeNotifier::AddMaxBandwidthObserver(&observer);
diff --git a/chromium/net/base/registry_controlled_domains/effective_tld_names.dat b/chromium/net/base/registry_controlled_domains/effective_tld_names.dat
index 69c78881f08..59db7d0c52f 100644
--- a/chromium/net/base/registry_controlled_domains/effective_tld_names.dat
+++ b/chromium/net/base/registry_controlled_domains/effective_tld_names.dat
@@ -4663,9 +4663,6 @@ web.ni
// ccTLD for the Netherlands
nl
-// BV.nl will be a registry for dutch BV's (besloten vennootschap)
-bv.nl
-
// no : http://www.norid.no/regelverk/index.en.html
// The Norwegian registry has declined to notify us of updates. The web pages
// referenced below are the official source of the data. There is also an
@@ -7111,9 +7108,6 @@ accountants
// aco : 2015-01-08 ACO Severin Ahlmann GmbH & Co. KG
aco
-// active : 2014-05-01 Active Network, LLC
-active
-
// actor : 2013-12-12 United TLD Holdco Ltd.
actor
@@ -7414,9 +7408,6 @@ black
// blackfriday : 2014-01-16 Uniregistry, Corp.
blackfriday
-// blanco : 2015-07-16 BLANCO GmbH + Co KG
-blanco
-
// blockbuster : 2015-07-30 Dish DBS Corporation
blockbuster
@@ -8026,9 +8017,6 @@ engineering
// enterprises : 2013-09-20 Binky Moon, LLC
enterprises
-// epost : 2015-07-23 Deutsche Post AG
-epost
-
// epson : 2014-12-04 Seiko Epson Corporation
epson
@@ -9850,9 +9838,6 @@ soy
// space : 2014-04-03 DotSpace Inc.
space
-// spiegel : 2014-02-05 SPIEGEL-Verlag Rudolf Augstein GmbH & Co. KG
-spiegel
-
// sport : 2017-11-16 Global Association of International Sports Federations (GAISF)
sport
@@ -10687,9 +10672,6 @@ zero
// zip : 2014-05-08 Charleston Road Registry Inc.
zip
-// zippo : 2015-07-02 Zadco Company
-zippo
-
// zone : 2013-11-14 Binky Moon, LLC
zone
@@ -11092,6 +11074,11 @@ firm.dk
reg.dk
store.dk
+// dapps.earth : https://dapps.earth/
+// Submitted by Daniil Burdakov <icqkill@gmail.com>
+*.dapps.earth
+*.bzz.dapps.earth
+
// Debian : https://www.debian.org/
// Submitted by Peter Palfrader / Debian Sysadmin Team <dsa-publicsuffixlist@debian.org>
debian.net
@@ -11638,6 +11625,7 @@ channelsdvr.net
// Fastly Inc. : http://www.fastly.com/
// Submitted by Fastly Security <security@fastly.com>
+fastly-terrarium.com
fastlylb.net
map.fastlylb.net
freetls.fastly.net
@@ -11672,6 +11660,12 @@ mydobiss.com
// Filegear Inc. : https://www.filegear.com
// Submitted by Jason Zhu <jason@owtware.com>
filegear.me
+filegear-au.me
+filegear-de.me
+filegear-gb.me
+filegear-ie.me
+filegear-jp.me
+filegear-sg.me
// Firebase, Inc.
// Submitted by Chris Raynor <chris@firebase.com>
@@ -11734,6 +11728,8 @@ goip.de
// Google, Inc.
// Submitted by Eduardo Vela <evn@google.com>
+run.app
+a.run.app
*.0emm.com
appspot.com
blogspot.ae
@@ -11853,6 +11849,19 @@ moonscale.net
// Submitted by Hannu Aronsson <haa@iki.fi>
iki.fi
+// Individual Network Berlin e.V. : https://www.in-berlin.de/
+// Submitted by Christian Seitz <chris@in-berlin.de>
+dyn-berlin.de
+in-berlin.de
+in-brb.de
+in-butter.de
+in-dsl.de
+in-dsl.net
+in-dsl.org
+in-vpn.de
+in-vpn.net
+in-vpn.org
+
// info.at : http://www.info.at/
biz.at
info.at
@@ -11939,6 +11948,22 @@ git-repos.de
lcube-server.de
svn-repos.de
+// Leadpages : https://www.leadpages.net
+// Submitted by Greg Dallavalle <domains@leadpages.net>
+leadpages.co
+lpages.co
+lpusercontent.com
+
+// Lifetime Hosting : https://Lifetime.Hosting/
+// Submitted by Mike Fillator <support@lifetime.hosting>
+co.business
+co.education
+co.events
+co.financial
+co.network
+co.place
+co.technology
+
// Lightmaker Property Manager, Inc. : https://app.lmpm.com/
// Submitted by Greg Holland <greg.holland@lmpm.com>
app.lmpm.com
@@ -12494,6 +12519,10 @@ spacekit.io
// Submitted by Stefan Neufeind <info@speedpartner.de>
customer.speedpartner.de
+// Standard Library : https://stdlib.com
+// Submitted by Jacob Lee <jacob@stdlib.com>
+api.stdlib.com
+
// Storj Labs Inc. : https://storj.io/
// Submitted by Philip Hutchins <hostmaster@storj.io>
storj.farm
@@ -12506,6 +12535,11 @@ utwente.io
// Submitted by Dan Miller <dm@sub6.com>
temp-dns.com
+// Swisscom Application Cloud: https://developer.swisscom.com
+// Submitted by Matthias.Winzeler <matthias.winzeler@swisscom.com>
+applicationcloud.io
+scapp.io
+
// Synology, Inc. : https://www.synology.com/
// Submitted by Rony Weng <ronyweng@synology.com>
diskstation.me
@@ -12534,6 +12568,12 @@ gdynia.pl
med.pl
sopot.pl
+// Telebit : https://telebit.cloud
+// Submitted by AJ ONeal <aj@telebit.cloud>
+telebit.app
+telebit.io
+*.telebit.xyz
+
// The Gwiddle Foundation : https://gwiddlefoundation.org.uk
// Submitted by Joshua Bayfield <joshua.bayfield@gwiddlefoundation.org.uk>
gwiddle.co.uk
@@ -12693,6 +12733,10 @@ za.org
// Submitted by Olli Vanhoja <olli@zeit.co>
now.sh
+// Zine EOOD : https://zine.bg/
+// Submitted by Martin Angelov <martin@zine.bg>
+bss.design
+
// Zone.id : https://zone.id/
// Submitted by Su Hendro <admin@zone.id>
zone.id
diff --git a/chromium/net/base/registry_controlled_domains/effective_tld_names.gperf b/chromium/net/base/registry_controlled_domains/effective_tld_names.gperf
index 9443898779d..56f3713b15e 100644
--- a/chromium/net/base/registry_controlled_domains/effective_tld_names.gperf
+++ b/chromium/net/base/registry_controlled_domains/effective_tld_names.gperf
@@ -44,6 +44,7 @@ struct DomainRule {
9guacu.br, 0
a.bg, 0
a.prod.fastly.net, 4
+a.run.app, 4
a.se, 0
a.ssl.fastly.net, 4
aa.no, 0
@@ -129,7 +130,6 @@ achi.nagano.jp, 0
aco, 0
act.au, 0
act.edu.au, 0
-active, 0
actor, 0
ad, 0
ad.jp, 0
@@ -337,6 +337,7 @@ ap.it, 0
ap.leg.br, 4
aparecida.br, 0
apartments, 0
+api.stdlib.com, 4
apigee.io, 4
app, 0
app.lmpm.com, 4
@@ -344,6 +345,7 @@ app.os.fedoraproject.org, 4
app.os.stg.fedoraproject.org, 4
appchizi.com, 4
apple, 0
+applicationcloud.io, 4
applinzi.com, 4
apps.fbsbx.com, 4
apps.lair.io, 4
@@ -732,7 +734,6 @@ bl.it, 0
black, 0
blackbaudcdn.net, 4
blackfriday, 0
-blanco, 0
blockbuster, 0
blog, 0
blog.bo, 0
@@ -910,6 +911,7 @@ bryne.no, 0
bs, 0
bs.it, 0
bsb.br, 0
+bss.design, 4
bt, 0
bt.it, 0
bu.no, 0
@@ -936,7 +938,6 @@ buyshouses.net, 4
buzen.fukuoka.jp, 0
buzz, 0
bv, 0
-bv.nl, 0
bw, 0
by, 0
bydgoszcz.pl, 0
@@ -947,6 +948,7 @@ bytom.pl, 0
bz, 0
bz.it, 0
bzh, 0
+bzz.dapps.earth, 6
c.bg, 0
c.cdn77.org, 4
c.la, 4
@@ -1275,6 +1277,7 @@ co.ao, 0
co.at, 0
co.bb, 0
co.bi, 0
+co.business, 4
co.bw, 0
co.ca, 4
co.ci, 0
@@ -1284,6 +1287,9 @@ co.com, 4
co.cr, 0
co.cz, 4
co.dk, 4
+co.education, 4
+co.events, 4
+co.financial, 4
co.gg, 0
co.gl, 0
co.gy, 0
@@ -1308,18 +1314,21 @@ co.mu, 0
co.mw, 0
co.mz, 0
co.na, 0
+co.network, 4
co.ni, 0
co.nl, 4
co.no, 4
co.nz, 0
co.om, 0
co.pl, 4
+co.place, 4
co.pn, 0
co.pw, 0
co.rs, 0
co.rw, 0
co.st, 0
co.sz, 0
+co.technology, 4
co.th, 0
co.tj, 0
co.tm, 0
@@ -1625,6 +1634,7 @@ dallas.museum, 0
damnserver.com, 4
dance, 0
daplie.me, 4
+dapps.earth, 6
data, 0
database.museum, 0
date, 0
@@ -1801,6 +1811,7 @@ dvr, 0
dvrcam.info, 4
dvrdns.org, 4
dy.fi, 4
+dyn-berlin.de, 4
dyn-ip24.de, 4
dyn-o-saur.com, 4
dyn-vpn.de, 4
@@ -2061,7 +2072,6 @@ entomology.museum, 0
environment.museum, 0
environmentalconservation.museum, 0
epilepsy.museum, 0
-epost, 0
epson, 0
equipment, 0
equipment.aero, 0
@@ -2156,6 +2166,7 @@ farmstead.museum, 0
farsund.no, 0
fashion, 0
fast, 0
+fastly-terrarium.com, 4
fastlylb.net, 4
fastpanel.direct, 4
fastvps-server.com, 4
@@ -2196,6 +2207,12 @@ fie.ee, 0
field.museum, 0
figueres.museum, 0
filatelia.museum, 0
+filegear-au.me, 4
+filegear-de.me, 4
+filegear-gb.me, 4
+filegear-ie.me, 4
+filegear-jp.me, 4
+filegear-sg.me, 4
filegear.me, 4
film, 0
film.hu, 0
@@ -3268,7 +3285,16 @@ immobilien, 0
imperia.it, 0
in, 0
in-addr.arpa, 0
+in-berlin.de, 4
+in-brb.de, 4
+in-butter.de, 4
+in-dsl.de, 4
+in-dsl.net, 4
+in-dsl.org, 4
in-the-band.net, 4
+in-vpn.de, 4
+in-vpn.net, 4
+in-vpn.org, 4
in.eu.org, 4
in.futurecms.at, 6
in.na, 0
@@ -4153,6 +4179,7 @@ lc.it, 0
lcube-server.de, 4
lds, 0
le.it, 0
+leadpages.co, 4
leangaviika.no, 0
lease, 0
leasing.aero, 0
@@ -4322,8 +4349,10 @@ louvre.museum, 0
love, 0
lowicz.pl, 0
loyalist.museum, 0
+lpages.co, 4
lpl, 0
lplfinancial, 0
+lpusercontent.com, 4
lr, 0
ls, 0
lt, 0
@@ -6378,6 +6407,7 @@ ru.net, 4
rugby, 0
ruhr, 0
run, 0
+run.app, 4
ruovat.no, 0
russia.museum, 0
rv.ua, 0
@@ -6587,6 +6617,7 @@ sc.tz, 0
sc.ug, 0
sc.us, 0
sca, 0
+scapp.io, 4
scb, 0
sch.ae, 0
sch.id, 0
@@ -6979,7 +7010,6 @@ spdns.de, 4
spdns.eu, 4
spdns.org, 4
spectrum.myjino.ru, 6
-spiegel, 0
spjelkavik.no, 0
sport, 0
sport.hu, 0
@@ -7267,6 +7297,9 @@ tecnologia.bo, 0
tel, 0
tel.tr, 0
tele.amune.org, 4
+telebit.app, 4
+telebit.io, 4
+telebit.xyz, 6
telefonica, 0
telekommunikation.museum, 0
television.museum, 0
@@ -8636,7 +8669,6 @@ zgorzelec.pl, 0
zhitomir.ua, 0
zhytomyr.ua, 0
zip, 0
-zippo, 0
zj.cn, 0
zlg.br, 0
zm, 0
diff --git a/chromium/net/base/network_change_notifier_chromeos.cc b/chromium/net/base/network_change_notifier_posix.cc
index 6eb948b6a22..89a1ff461ce 100644
--- a/chromium/net/base/network_change_notifier_chromeos.cc
+++ b/chromium/net/base/network_change_notifier_posix.cc
@@ -5,14 +5,19 @@
#include <string>
#include "base/bind.h"
-#include "net/base/network_change_notifier_chromeos.h"
+#include "build/build_config.h"
+#include "net/base/network_change_notifier_posix.h"
#include "net/dns/dns_config_service_posix.h"
+#if defined(OS_ANDROID)
+#include "net/android/network_change_notifier_android.h"
+#endif
+
namespace net {
-// DNS config services on Chrome OS are signalled by the network state handler
-// rather than relying on watching files in /etc.
-class NetworkChangeNotifierChromeos::DnsConfigService
+// DNS config services on Chrome OS and Android are signalled by the network
+// state handler rather than relying on watching files in /etc.
+class NetworkChangeNotifierPosix::DnsConfigService
: public net::internal::DnsConfigServicePosix {
public:
DnsConfigService() = default;
@@ -32,21 +37,21 @@ class NetworkChangeNotifierChromeos::DnsConfigService
}
};
-NetworkChangeNotifierChromeos::NotifierThread::NotifierThread()
+NetworkChangeNotifierPosix::NotifierThread::NotifierThread()
: base::Thread("NetworkChangeNotifier") {
DETACH_FROM_SEQUENCE(sequence_checker_);
}
-NetworkChangeNotifierChromeos::NotifierThread::~NotifierThread() {
+NetworkChangeNotifierPosix::NotifierThread::~NotifierThread() {
DCHECK(!Thread::IsRunning());
}
-void NetworkChangeNotifierChromeos::NotifierThread::OnNetworkChange() {
+void NetworkChangeNotifierPosix::NotifierThread::OnNetworkChange() {
DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
dns_config_service_->OnNetworkChange();
}
-void NetworkChangeNotifierChromeos::NotifierThread::Init() {
+void NetworkChangeNotifierPosix::NotifierThread::Init() {
DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
dns_config_service_.reset(new DnsConfigService());
dns_config_service_->WatchConfig(
@@ -54,42 +59,44 @@ void NetworkChangeNotifierChromeos::NotifierThread::Init() {
dns_config_service_->OnNetworkChange();
}
-void NetworkChangeNotifierChromeos::NotifierThread::CleanUp() {
+void NetworkChangeNotifierPosix::NotifierThread::CleanUp() {
DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
dns_config_service_.reset();
}
-NetworkChangeNotifierChromeos::NetworkChangeNotifierChromeos()
- : NetworkChangeNotifier(NetworkChangeCalculatorParamsChromeos()),
- connection_type_(CONNECTION_NONE),
+NetworkChangeNotifierPosix::NetworkChangeNotifierPosix(
+ NetworkChangeNotifier::ConnectionType initial_connection_type,
+ NetworkChangeNotifier::ConnectionSubtype initial_connection_subtype)
+ : NetworkChangeNotifier(NetworkChangeCalculatorParamsPosix()),
+ connection_type_(initial_connection_type),
max_bandwidth_mbps_(
NetworkChangeNotifier::GetMaxBandwidthMbpsForConnectionSubtype(
- SUBTYPE_NONE)) {
+ initial_connection_subtype)) {
notifier_thread_.StartWithOptions(
base::Thread::Options(base::MessageLoop::TYPE_IO, 0));
}
-NetworkChangeNotifierChromeos::~NetworkChangeNotifierChromeos() {
+NetworkChangeNotifierPosix::~NetworkChangeNotifierPosix() {
notifier_thread_.Stop();
}
-void NetworkChangeNotifierChromeos::OnDNSChanged() {
+void NetworkChangeNotifierPosix::OnDNSChanged() {
DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
// The Unretained thread pointer is ok here because if the thread gets
// deleted, the callback won't be called.
notifier_thread_.task_runner()->PostTask(
FROM_HERE,
base::BindOnce(
- &NetworkChangeNotifierChromeos::NotifierThread::OnNetworkChange,
+ &NetworkChangeNotifierPosix::NotifierThread::OnNetworkChange,
base::Unretained(&notifier_thread_)));
}
-void NetworkChangeNotifierChromeos::OnIPAddressChanged() {
+void NetworkChangeNotifierPosix::OnIPAddressChanged() {
DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
NetworkChangeNotifier::NotifyObserversOfIPAddressChange();
}
-void NetworkChangeNotifierChromeos::OnConnectionChanged(
+void NetworkChangeNotifierPosix::OnConnectionChanged(
NetworkChangeNotifier::ConnectionType connection_type) {
DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
{
@@ -99,7 +106,7 @@ void NetworkChangeNotifierChromeos::OnConnectionChanged(
NetworkChangeNotifier::NotifyObserversOfConnectionTypeChange();
}
-void NetworkChangeNotifierChromeos::OnConnectionSubtypeChanged(
+void NetworkChangeNotifierPosix::OnConnectionSubtypeChanged(
NetworkChangeNotifier::ConnectionType connection_type,
NetworkChangeNotifier::ConnectionSubtype connection_subtype) {
DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
@@ -114,12 +121,12 @@ void NetworkChangeNotifierChromeos::OnConnectionSubtypeChanged(
}
NetworkChangeNotifier::ConnectionType
-NetworkChangeNotifierChromeos::GetCurrentConnectionType() const {
+NetworkChangeNotifierPosix::GetCurrentConnectionType() const {
base::AutoLock scoped_lock(lock_);
return connection_type_;
}
-void NetworkChangeNotifierChromeos::GetCurrentMaxBandwidthAndConnectionType(
+void NetworkChangeNotifierPosix::GetCurrentMaxBandwidthAndConnectionType(
double* max_bandwidth_mbps,
ConnectionType* connection_type) const {
base::AutoLock scoped_lock(lock_);
@@ -129,8 +136,9 @@ void NetworkChangeNotifierChromeos::GetCurrentMaxBandwidthAndConnectionType(
// static
NetworkChangeNotifier::NetworkChangeCalculatorParams
-NetworkChangeNotifierChromeos::NetworkChangeCalculatorParamsChromeos() {
+NetworkChangeNotifierPosix::NetworkChangeCalculatorParamsPosix() {
NetworkChangeCalculatorParams params;
+#if defined(OS_CHROMEOS)
// Delay values arrived at by simple experimentation and adjusted so as to
// produce a single signal when switching between network connections.
params.ip_address_offline_delay_ = base::TimeDelta::FromMilliseconds(4000);
@@ -138,6 +146,12 @@ NetworkChangeNotifierChromeos::NetworkChangeCalculatorParamsChromeos() {
params.connection_type_offline_delay_ =
base::TimeDelta::FromMilliseconds(500);
params.connection_type_online_delay_ = base::TimeDelta::FromMilliseconds(500);
+#elif defined(OS_ANDROID)
+ params =
+ net::NetworkChangeNotifierAndroid::NetworkChangeCalculatorParamsAndroid();
+#else
+ NOTIMPLEMENTED();
+#endif
return params;
}